# turbo_dash
automated Dash framework with templates

## Quickstart
`pip install turbo-dash`

## Usage
- Multi Page App:
  - `./app.py` - initialize the app and server
  - `./index.py` - callback for page content Div (run this file to run the app)
  - `./homepage.py` - homepage layout and callback
  - `./app1.py` - app1 layout and callback
  - `./app2.py` - app2 layout and callback
  - `./fourohfour.py` - fourohfour layout and callback
